% PHfn_ss.m: a most inelegant way to determine the necessary pulse height
% for a given desired saccade.  These numbers were obtained with "PHcalc"
% using method 2.  The model in "testbed" was "Pulse+NI->OMN->Plant".
% Eye position was measured at its steady state (400ms after end of pulse),
% and a constant tonic gain of 5.25.
%
% For reasons I can not yet explain, these values are calculated with a tonic
% gain of 5.25, yet are slightly too large with that value when tested
% in "PG+NI->OMN->Plant"  But if the tonic gain in that block is dropped
% to 5.125 then everything looks very good.  Hmmmm.
% The problem _MAY_ be due to invoking the model from the command line vs 
% running it with "Start Simulation"  Shouldn't be different, but may be.

% Written by:  Jonathan Jacobs
%              October 1998 - February 1999 (last mod: 02/18/99)

function out = PHfn_ss(in);

sgn = sign(in);
in = abs(in);

if in > 50
   in = 50;
end

% teeny tiny saccades -- 0.05 to 0.09 degrees
smallmag = [0.6366    0.7635    0.8903    1.0170    1.1438];
if in < 0.05, out = 0; return; end
if (in >= 0.05) & (in < 0.1)
   ind = fix((in-0.04)*100);
   if ind==0; ind=1;end
   out = smallmag(ind)*sgn;
   return
end

% we go by 2.5 degree increments so that we only have to load
% small (25 element) matrices.  If we had to load in values for
% all fifty degrees at once, it would make the model unbearably slow.
%%% this seems to be the best tradeoff between speed and partitioning effort
if (in >= 0.1) & (in <= 2.5)
   mag = [...
       1.2732    2.5449    3.8155    5.0852    6.3542 ...  %% 0.1 - 0.5
       7.6228    8.8910   10.1590   11.4269   12.6946 ...  %% 0.6 - 1
      13.9623   15.2300   16.4977   17.7654   19.0331 ...  %% 1.1 - 1.5
      20.3009   21.5688   22.8366   24.1046   25.3725 ...  %% 1.6 - 2
      26.6406   27.9086   29.1767   30.4449   31.7131 ...  %% 2.1 - 2.5
    ];
   ind = round(in*10);
   out = mag(ind)*sgn;
   return
end


if (in > 2.5) & (in <= 5.0)
   mag = [...
      32.9813   34.2495   35.5177   36.7860   38.0543 ...  %% 2.6 - 3
      39.3226   40.5910   41.8593   43.1277   44.3961 ...  %% 3.1 - 3.5
      45.6644   46.9328   48.2012   49.4696   50.7380 ...  %% 3.6 - 4
      52.0064   53.2749   54.5433   55.8117   57.0801 ...  %% 4.1 - 4.5
      58.3486   59.6170   60.8854   62.1538   63.4223 ...  %% 4.6 - 5
    ];
   ind = round((in-2.5)*10);
   if ind==0; ind=1;end
   out = mag(ind)*sgn;
   return
end


if (in > 5) & (in <= 7.5)
   mag = [...
      64.6907   65.9592   67.2276   68.4960   69.7645 ...  %% 5.1 - 5.5
      71.0329   72.3014   69.2340   70.3865   71.5447 ...  %% 5.6 - 6
      72.7076   73.8747   75.0451   76.2185   77.3944 ...  %% 6.1 - 6.5
      78.5724   79.7522   76.4592   77.5283   78.6059 ...  %% 6.6 - 7
      79.6905   80.7809   81.8763   82.9757   84.0786 ...  %% 7.1 - 7.5
    ];
   ind = round((in-5)*10);
   if ind==0; ind=1;end
   out = mag(ind)*sgn;
   return
end

if (in > 7.5) & (in <= 10.0)
   mag = [...
      85.1843   86.2924   82.8469   83.8477   84.8586 ...  %% 7.6 - 8
      85.8779   86.9042   87.9361   88.9727   90.0131 ...  %% 8.1 - 8.5
      91.0566   92.1028   88.5749   89.5126   90.4626 ...  %% 8.6 - 9
      91.4226   92.3907   93.3654   94.3455   95.3298 ...  %% 9.1 - 9.5
      96.3176   97.3083   93.6681   94.5619   95.4677 ...  %% 9.6 - 10
    ];
   ind = round((in-7.5)*10);
   if ind==0; ind=1;end
   out = mag(ind)*sgn;
   return
end


if (in > 10) & (in <= 12.5)
   mag = [...
      96.3829   97.3057   98.2346   94.7130   95.5548 ...  %% 10.1 - 10.5
      96.4106   97.2775   98.1530   94.8065   95.5987 ...  %% 10.6 - 11
      96.4076   97.2295   98.0613   94.8181   95.5822 ...  %% 11.1 - 11.5
      96.3616   97.1527   97.9528   94.8341   95.5726 ...  %% 11.6 - 12
      96.3249   97.0877   97.8583   94.9234   95.6205 ...  %% 12.1 - 12.5
    ];
   ind = round((in-10)*10);
   if ind==0; ind=1;end
   out = mag(ind)*sgn;
   return
end
 
if (in > 12.5) & (in <= 15.0)
   mag = [...
      96.3345   97.0612   97.7973   94.9418   95.6175 ...  %% 12.6 - 13
      96.3089   97.0117   97.7229   94.9630   95.6190 ...  %% 13.1 - 13.5
      96.2892   96.9698   97.6577   95.0522   95.6710 ...  %% 13.6 - 14
      96.3081   96.9581   97.6175   95.0731   95.6755 ...  %% 14.1 - 14.5
      96.2948   96.9259   97.5654   95.0959   95.6831 ...  %% 14.6 - 15
    ];
   ind = round((in-12.5)*10);
  if ind==0; ind=1;end
  out = mag(ind)*sgn;
  return
end


if (in > 15) & (in <= 17.5)
   mag = [...
      96.2857   96.8990   97.5197   95.1874   95.7388 ...  %% 15.1 - 15.5
      96.3112   96.8978   97.4940   95.2086   95.7475 ...  %% 15.6 - 16
      96.3058   96.8771   97.4572   95.2310   95.7583 ...  %% 16.1 - 16.5
      96.3034   96.8603   97.4250   95.2555   95.7715 ...  %% 16.6 - 17
      96.3039   96.8470   97.3971   95.2816   95.7868 ...  %% 17.1 - 17.5
    ];
   ind = round((in-15.0)*10);
  if ind==0; ind=1;end
  out = mag(ind)*sgn;
  return
end
 
if (in > 17.5) & (in <= 20.0)
   mag = [...
      96.3070   96.8370   97.3730   95.3693   95.8416 ...  %% 17.6 - 18
      96.3361   96.8445   97.3617   95.3926   95.8562 ...  %% 18.1 - 18.5
      96.3406   96.8377   97.3426   95.4167   95.8722 ...  %% 18.6 - 19
      96.3468   96.8331   97.3264   95.4421   95.8896 ...  %% 19.1 - 19.5
      96.3549   96.8307   97.3128   95.4685   95.9083 ...  %% 19.6 - 20
    ];
   ind = round((in-17.5)*10);
   if ind==0; ind=1;end
   out = mag(ind)*sgn;
   return
end


if (in > 20) & (in <= 22.5)
   mag = [...
      96.3645   96.8302   97.3016   95.4958   95.9282 ...  %% 20.1 - 20.5
      96.3755   96.8315   97.2925   95.5239   95.9489 ...  %% 20.6 - 21
      96.3877   96.8343   97.2853   95.6043   95.9992 ...  %% 21.1 - 21.5
      96.4169   96.8473   97.2848   95.6291   96.0185 ...  %% 21.6 - 22
      96.4292   96.8516   97.2802   95.6544   96.0386 ...  %% 22.1 - 22.5
    ];
   ind = round((in-20.0)*10);
   if ind==0; ind=1;end
   out = mag(ind)*sgn;
   return
end


if (in > 22.5) & (in <= 25.0)
   mag = [...
      96.4425   96.8571   97.2772   95.6805   96.0594 ...  %% 22.6 - 23
      96.4568   96.8637   97.2757   95.7071   96.0810 ...  %% 23.1 - 23.5
      96.4718   96.8714   97.2754   95.7343   96.1031 ...  %% 23.6 - 24
      96.4877   96.8800   97.2763   95.7619   96.1258 ...  %% 24.1 - 24.5
      96.5041   96.8895   97.2784   95.7899   96.1489 ...  %% 24.6 - 25
    ];
   ind = round((in-22.5)*10);
   if ind==0; ind=1;end
   out = mag(ind)*sgn;
   return
end


if (in > 25) & (in <= 27.5)
   mag = [...
      96.5212   96.8998   97.2814   95.8182   96.1724 ...  %% 25.1 - 25.5
      96.5388   96.9108   97.2854   95.8914   96.2169 ...  %% 25.6 - 26
      96.5663   96.9267   97.2923   95.9165   96.2388 ...  %% 26.1 - 26.5
      96.5836   96.9383   97.2976   95.9418   96.2612 ...  %% 26.6 - 27
      96.6013   96.9505   97.3038   95.9676   96.2840 ...  %% 27.1 - 27.5
     ];
   ind = round((in-25.0)*10);
   if ind==0; ind=1;end
   out = mag(ind)*sgn;
   return
end


if (in > 27.5) & (in <= 30.0)
   mag = [...
      96.6195   96.9633   97.3106   95.9937   96.3071 ...  %% 27.6 - 28
      96.6381   96.9766   97.3182   96.0202   96.3304 ...  %% 28.1 - 28.5
      96.6570   96.9903   97.3264   96.0469   96.3541 ...  %% 28.6 - 29
      96.6763   97.0045   97.3351   96.0738   96.3780 ...  %% 29.1 - 29.5
      96.6959   97.0191   97.3445   96.1010   96.4021 ...  %% 29.6 - 30
    ];
   ind = round((in-27.5)*10);
   if ind==0; ind=1;end
   out = mag(ind)*sgn;
   return
end


if (in > 30) & (in <= 32.5)
   mag = [...
      96.7157   97.0341   97.3543   96.1283   96.4263 ...  %% 30.1 - 30.5
      96.7358   97.0494   97.3646   96.1558   96.4507 ...  %% 30.6 - 31
      96.7560   97.0650   97.3754   96.1834   96.4752 ...  %% 31.1 - 31.5
      96.7764   97.0809   97.3866   96.2110   96.4998 ...  %% 31.6 - 32
      96.7970   97.0971   97.3982   96.2388   96.5245 ...  %% 32.1 - 32.5
    ];
   ind = round((in-30.0)*10);
   if ind==0; ind=1;end
   out = mag(ind)*sgn;
   return
end


if (in > 32.5) & (in <= 35.0)
   mag = [...
      96.8178   97.1135   97.4101   96.2981   96.5592 ...  %% 32.6 - 33
      96.8418   97.1312   97.4227   96.3230   96.5827 ...  %% 33.1 - 33.5
      96.8623   97.1478   97.4353   96.3481   96.6064 ...  %% 33.6 - 34
      96.8829   97.1647   97.4482   96.3734   96.6303 ...  %% 34.1 - 34.5
      96.9037   97.1818   97.4613   96.3988   96.6542 ...  %% 34.6 - 35
    ];
   ind = round((in-32.5)*10);
   if ind==0; ind=1;end
   out = mag(ind)*sgn;
   return
end


if (in > 35) & (in <= 37.5)
   mag = [...
      96.9246   97.1991   97.4748   96.4245   96.6782 ...  %% 35.1 - 35.5
      96.9456   97.2166   97.4885   96.4502   96.7023 ...  %% 35.6 - 36
      96.9667   97.2342   97.5025   96.4761   96.7264 ...  %% 36.1 - 36.5
      96.9878   97.2519   97.5167   96.5020   96.7506 ...  %% 36.6 - 37
      97.0091   97.2698   97.5311   96.5281   96.7749 ...  %% 37.1 - 37.5
    ];
   ind = round((in-35.0)*10);
   if ind==0; ind=1;end
   out = mag(ind)*sgn;
   return
end


if (in > 37.5) & (in <= 40.0)
   mag = [...
      97.0304   97.2879   97.5458   96.5542   96.7991 ...  %% 37.6 - 38
      97.0517   97.3060   97.5606   96.5804   96.8234 ...  %% 38.1 - 38.5
      97.0731   97.3242   97.5756   96.6066   96.8476 ...  %% 38.6 - 39
      97.0945   97.3426   97.5908   96.6328   96.8719 ...  %% 39.1 - 39.5
      97.1160   97.3610   97.6062   96.6591   96.8961 ...  %% 39.6 - 40
    ];
   ind = round((in-37.5)*10);
   if ind==0; ind=1;end
   out = mag(ind)*sgn;
   return
end


if (in > 40) & (in <= 42.5)
   mag = [...
      97.1374   97.3795   97.6217   96.6854   96.9203 ...  %% 40.1 - 40.5
      97.1589   97.3981   97.6374   96.7117   96.9445 ...  %% 40.6 - 41
      97.1804   97.4168   97.6532   96.7380   96.9687 ...  %% 41.1 - 41.5
      97.2019   97.4355   97.6691   96.7642   96.9928 ...  %% 41.6 - 42
      97.2234   97.4543   97.6852   96.7904   97.0168 ...  %% 42.1 - 42.5
    ];
   ind = round((in-40.0)*10);
   if ind==0; ind=1;end
   out = mag(ind)*sgn;
   return
end


if (in > 42.5) & (in <= 45.0)
   mag = [...
      97.2449   97.4731   97.7014   96.8166   97.0408 ...  %% 42.6 - 43
      97.2664   97.4920   97.7177   96.8428   97.0648 ...  %% 43.1 - 43.5
      97.2878   97.5109   97.7341   96.8775   97.0895 ...  %% 43.6 - 44
      97.3094   97.5299   97.7506   96.9018   97.1131 ...  %% 44.1 - 44.5
      97.3308   97.5490   97.7672   96.9262   97.1367 ...  %% 44.6 - 45
    ];
   ind = round((in-42.5)*10);
   out = mag(ind)*sgn;
   return
end


if (in > 45) & (in <= 47.5)
   mag = [... 
      97.3522   97.5680   97.7839   96.9507   97.1603 ...  %% 45.1 - 45.5
      97.3736   97.5871   97.8006   96.9754   97.1838 ...  %% 45.6 - 46
      97.3949   97.6062   97.8175   97.0001   97.2073 ...  %% 46.1 - 46.5
      97.4163   97.6253   97.8344   97.0250   97.2308 ...  %% 46.6 - 47
      97.4376   97.6445   97.8514   97.0500   97.2542 ...  %% 47.1 - 47.5
    ];
   ind = round((in-45.0)*10);
   if ind==0; ind=1;end
   out = mag(ind)*sgn;
   return
end


if (in > 47.5) & (in <= 50.0)
   mag = [...
      97.4589   97.6637   97.8684   97.0751   97.2776 ...  %% 47.6 - 48
      97.4802   97.6829   97.8855   97.1002   97.3008 ...  %% 48.1 - 48.5
      97.5015   97.7021   97.9027   97.1255   97.3241 ...  %% 48.6 - 49
      97.5227   97.7213   97.9199   97.1508   97.3472 ...  %% 49.1 - 49.5
      97.5439   97.7405   97.9372   97.1763   97.3703 ...  %% 49.6 - 50
    ];
   ind = round((in-47.5)*10);
   if ind==0; ind=1;end
   out = mag(ind)*sgn;
   return
end
